@@ -74,6 +74,9 @@ class VersionFlagTests(TestCase):
             with self.subTest(msg=command):
                 self.assertReturncode([f"{self.output}/bin/{command}", "--version"], 0)
 
+    def tearDown(self) -> None:
+        shutil.rmtree(self.directory)
+
 
 @network
 @requires_nix_build
@@ -122,6 +125,9 @@ class JsonIntegrityTests(TestCase):
         self.output = path.join(self.directory, "result")
         subprocess.run(["nix", "build", "--out-link", self.output], capture_output=True)
 
+    def tearDown(self) -> None:
+        shutil.rmtree(self.directory)
+
     def test_can_load_json_output_as_json(self) -> None:
         expressions = [
             [
@@ -142,9 +148,22 @@ class JsonIntegrityTests(TestCase):
             ],
         ]
         for expression in expressions:
-            with self.subTest(msg=shlex.join(expression)):
-                finished_process = subprocess.run(expression, capture_output=True)
-                self.assertEqual(finished_process.returncode, 0)
+            expression_shell_command = shlex.join(expression)
+            with self.subTest(msg=expression_shell_command):
+                finished_process = subprocess.run(
+                    expression, capture_output=True, universal_newlines=True
+                )
+                self.assertEqual(
+                    finished_process.returncode,
+                    0,
+                    msg="\n".join(
+                        [
+                            f"Failed to execute {expression_shell_command}.",
+                            f"stdout: {finished_process.stdout}",
+                            f"stderr: {finished_process.stderr}",
+                        ]
+                    ),
+                )
                 json.loads(finished_process.stdout)
 
     def test_can_use_json_output_as_input_for_fetch_from_github(self) -> None:
@@ -170,9 +189,6 @@ class JsonIntegrityTests(TestCase):
             cwd=self.directory,
         )
 
-    def tearDown(self) -> None:
-        shutil.rmtree(self.directory)
-
 
 if __name__ == "__main__":
     unittest.main()
